#ifndef UT_REMOTE_H
#define UT_REMOTE_H

#include <QObject>
#include <QWaitCondition>

class Remote;

class Ut_Remote : public QObject
{
    Q_OBJECT

private slots:
    void initTestCase();
    void cleanupTestCase();
    void init();
    void cleanup();

    void testSaveToFile_normal();
    void testSaveToFile_emptyname();
    void testUpdateInfo_normal();
    void testUpdateInfo_emptyname();
    void testSendRating_up();
    void testSendRating_down();

public slots:
    void wakeTest();

private:
    Remote *subject;
    QWaitCondition cond;
};

#endif // UT_REMOTE_H


